@@ -1,6 +1,6 @@
 package Devel::Confess;
 BEGIN {
-  my $can_use_informative_names = $] >= 5.008;
+  my $can_use_informative_names = "$]" >= 5.008;
   # detect -d:Confess.  disable debugger features for now.  we'll
   # enable them when we need them.
   if (!defined &DB::DB && $^P & 0x02) {
@@ -16,28 +16,38 @@ use strict;
 use warnings;
 no warnings 'once';
 
-our $VERSION = '0.009002';
+our $VERSION = '0.009003';
 $VERSION = eval $VERSION;
 
 use Carp ();
 use Symbol ();
-use Devel::Confess::_Util qw(blessed refaddr weaken longmess _str_val _in_END _can_stringify);
+use Devel::Confess::_Util qw(
+  blessed
+  refaddr
+  weaken
+  longmess
+  _str_val
+  _in_END
+  _can_stringify
+  _can
+  _isa
+);
 use Config ();
 BEGIN {
-  *_can = \&UNIVERSAL::can;
-
   *_BROKEN_CLONED_DESTROY_REBLESS
-    = ($] >= 5.008009 && $] < 5.010000) ? sub () { 1 } : sub () { 0 };
+    = ("$]" >= 5.008009 && "$]" < 5.010000) ? sub () { 1 } : sub () { 0 };
   *_BROKEN_CLONED_GLOB_UNDEF
-    = ($] > 5.008009 && $] <= 5.010000) ? sub () { 1 } : sub () { 0 };
+    = ("$]" > 5.008009 && "$]" <= 5.010000) ? sub () { 1 } : sub () { 0 };
   *_BROKEN_SIG_DELETE
-    = ($] < 5.008008) ? sub () { 1 } : sub () { 0 };
+    = ("$]" < 5.008008) ? sub () { 1 } : sub () { 0 };
   *_DEBUGGING
     = (
       defined &Config::non_bincompat_options
         ? (grep $_ eq 'DEBUGGING', Config::non_bincompat_options())
         : ($Config::Config{ccflags} =~ /-DDEBUGGING\b/)
     ) ? sub () { 1 } : sub () { 0 };
+  my $inf = 9**9**9;
+  *_INF = sub () { $inf }
 }
 
 $Carp::Internal{+__PACKAGE__}++;
@@ -104,7 +114,7 @@ sub _parse_options {
       if ($NUMOPTS{$opt}) {
         $value
           = !defined $value ? 0
-          : !$value ? 1e10000
+          : !$value ? _INF
           : 0+$value;
       }
       $opts{$opt} = $value;
@@ -265,7 +275,7 @@ sub _ref_formatter {
   local $Data::Dumper::Purity = 0;
   local $Data::Dumper::Terse = 1;
   local $Data::Dumper::Useqq = 1;
-  local $Data::Dumper::Maxdepth = $OPTIONS{dump} eq 'inf' ? 0 : $OPTIONS{dump};
+  local $Data::Dumper::Maxdepth = $OPTIONS{dump} == _INF ? 0 : $OPTIONS{dump};
   Data::Dumper::Dumper($_[0]);
 }
 
@@ -329,7 +339,7 @@ sub _convert {
     my $id = refaddr($ex);
     if (defined $EXCEPTIONS{$id}) {
       return @_
-        if $ex->isa("Devel::Confess::_Attached");
+        if _isa($ex, "Devel::Confess::_Attached");
 
       # something is going very wrong.  possibly from a Safe compartment.
       # we probably broke something, but do the best we can.
@@ -457,31 +467,39 @@ sub _ex_as_strings {
   use overload
     fallback => 1,
     'bool' => sub {
+      package
+        Devel::Confess;
       my $ex = $_[0];
-      my $class = $PACKAGES{Devel::Confess::refaddr($ex)};
+      my $class = $PACKAGES{refaddr($ex)};
       my $newclass = ref $ex;
       bless $ex, $class;
-      my $out = !!$ex;
+      my $out = $ex ? !!1 : !!0;
       bless $ex, $newclass;
       return $out;
     },
     '0+' => sub {
+      package
+        Devel::Confess;
       my $ex = $_[0];
-      my $class = $PACKAGES{Devel::Confess::refaddr($ex)};
+      my $class = $PACKAGES{refaddr($ex)};
       my $newclass = ref $ex;
       bless $ex, $class;
-      my $out = 0+sprintf '%f', $ex;
+      my $out = 0+sprintf '%.20g', $ex;
       bless $ex, $newclass;
       return $out;
     },
     '""' => sub {
-      return join('', Devel::Confess::_ex_as_strings(@_));
+      package
+        Devel::Confess;
+      join('', _ex_as_strings(@_));
     },
   ;
 
   sub DESTROY {
+    package
+      Devel::Confess;
     my $ex = $_[0];
-    my $id = Devel::Confess::refaddr($ex);
+    my $id = refaddr($ex);
     my $class = delete $PACKAGES{$id} or return;
     delete $MESSAGES{$id};
     delete $EXCEPTIONS{$id};
@@ -490,7 +508,7 @@ sub _ex_as_strings {
 
     my $cloned;
     # delete_package is more complete, but can explode on some perls
-    if (Devel::Confess::_BROKEN_CLONED_GLOB_UNDEF && delete $Devel::Confess::CLONED{$id}) {
+    if (_BROKEN_CLONED_GLOB_UNDEF && delete $CLONED{$id}) {
       $cloned = 1;
       no strict 'refs';
       @{"${newclass}::ISA"} = ();
@@ -501,8 +519,8 @@ sub _ex_as_strings {
       Symbol::delete_package($newclass);
     }
 
-    if (Devel::Confess::_BROKEN_CLONED_DESTROY_REBLESS && $cloned || delete $Devel::Confess::CLONED{$id}) {
-      my $destroy = $class->can('DESTROY') || return;
+    if (_BROKEN_CLONED_DESTROY_REBLESS && $cloned || delete $CLONED{$id}) {
+      my $destroy = _can($class, 'DESTROY') || return;
       goto $destroy;
     }
 
