@@ -4,9 +4,19 @@ use strict;
 use warnings FATAL => 'all';
 no warnings 'once';
 
-use base 'Exporter';
+use Exporter (); BEGIN { *import = \&Exporter::import }
 
-our @EXPORT = qw(blessed refaddr weaken longmess _str_val _in_END _can_stringify);
+our @EXPORT = qw(
+  blessed
+  refaddr
+  weaken
+  longmess
+  _str_val
+  _in_END
+  _can_stringify
+  _can
+  _isa
+);
 
 use Carp ();
 use Carp::Heavy ();
@@ -159,7 +169,7 @@ eval q{
   }
 }
 
-if ($] < 5.008) {
+if ("$]" < 5.008) {
   eval q{
     sub _can_stringify () {
       my $i = 0;
@@ -185,4 +195,35 @@ else {
   } or die $@;
 }
 
+sub _isa;
+if ($INC{'UNIVERSAL/isa.pm'}) {
+  *__isa = \&UNIVERSAL::isa;
+  eval q{
+    sub _isa {
+      local $UNIVERSAL::isa::recursing = 1;
+      local $UNIVERSAL::isa::_recursing = 1;
+      __isa(@_);
+    }
+    1;
+  } or die $@;
+}
+else {
+  *_isa = \&UNIVERSAL::isa;
+}
+
+sub _can;
+if ($INC{'UNIVERSAL/can.pm'}) {
+  *__can = \&UNIVERSAL::can;
+  eval q{
+    sub _can {
+      local $UNIVERSAL::can::recursing = 1;
+      __can(@_);
+    }
+    1;
+  } or die $@;
+}
+else {
+  *_can = \&UNIVERSAL::can;
+}
+
 1;
